#
# spec file for package python-py7zr
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-py7zr%{psuffix}
Version:        1.0.0
Release:        1.1
Summary:        Library and utility to support 7zip
License:        LGPL-2.1-or-later
Group:          Development/Languages/Python
URL:            https://github.com/miurahr/py7zr
Source0:        https://files.pythonhosted.org/packages/source/p/py7zr/py7zr-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 63}
BuildRequires:  %{python_module setuptools_scm >= 7.0.5}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Brotli >= 1.1.0
Requires:       python-multivolumefile >= 0.2.3
Requires:       python-psutil
Requires:       python-pycryptodomex >= 3.20.0
Requires:       python-pyzstd >= 0.16.1
Requires:       python-texttable
Requires:       (python-inflate64 >= 1.0.0 with python-inflate64 < 1.1.0)
Requires:       (python-pybcj >= 1.0.0 with python-pybcj < 1.1.0)
Requires:       (python-pyppmd >= 1.1.0 with python-pyppmd < 1.3.0)
%if 0%{?python_version_nodots} < 38
Requires:       python-importlib_metadata
%endif
Requires(post): update-alternatives
Requires(postun): update-alternatives
%if %{with test}
BuildRequires:  %{python_module py-cpuinfo}
BuildRequires:  %{python_module py7zr = %{version}}
BuildRequires:  %{python_module pytest-benchmark}
BuildRequires:  %{python_module pytest-httpserver}
BuildRequires:  %{python_module pytest-remotedata}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
%endif
BuildArch:      noarch
%python_subpackages

%description
py7zr is a library and utility to support 7zip archive compression, decompression, encryption and decryption written by Python programming language.

%prep
%autosetup -p1 -n py7zr-%{version}
# remove shebangs from source
sed -i '1{/#!/d}' py7zr/*.py

%if !%{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/py7zr
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%pytest
%endif

%post
%python_install_alternative py7zr

%postun
%python_uninstall_alternative py7zr

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc README.rst docs/Changelog.rst
%{python_sitelib}/py7zr
%{python_sitelib}/py7zr-%{version}.dist-info
%python_alternative %{_bindir}/py7zr
%endif

%changelog
* Fri Jun 20 2025 ecsos <ecsos@opensuse.org>
- Update to 1.0.0
  * Changed
  - CI: check on Linux on ARM64 with GitHub hosted ARM64 runner.
  - Improve issue report template
  - Remove Travis-CI button from Documentation
- Changes from 0.22.0
  * Added
  - Add mode "x" for SevenZipFile (#588)
  - Add SevenZipFile#namelist method (#600)
  * Fixed
  - Append mode on non-existent files (#604)
  - Fix NUMBER encoding of integer when 8 bytes(#591)
  * Changed
  - Minimum required Python version to be Python 3.8 (#601)
  - Remove pyannotate from pyproject.toml (#598)
  * Document
  - Update user guide (#596)
- Changes from 0.21.1
  * Fixed
  - Follow shutil.register_unpack_format() convention of raising a ReadError when the library cannot handle a file (#583)
  - ensure unpack_7zarchive closes the archive (#584)
  - 64bit OS detection (#580)
  * Added
  - Add recursive sub-directories and files extraction (#585)
  * Changed
  - check targets argument type for read and extract method (#577)
  - Treat zero byte stream as a file (#551)
- Changes from 0.21.0
  * Changed
  - Speed up extraction when number of files is very large (#555)
  - Replace deprecated functions on python 3.12 (#550)
  * Added
  - Add report_update() for logging large files extraction (#558)
  * Document
  - Add subsection of multi-volume creation (#568)
- Drop py7zr-remove-pyannotate.patch because no more needed.
* Fri Feb 16 2024 Ben Greiner <code@bnavigator.de>
- Remove bogus unmaintained pyannotate test dependency
  * Add py7zr-remove-pyannotate.patch gh#miurahr/py7zr#552
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.20.8:
  * Detect brotli import error (#543)
  * refactor: hardening SevenZipFile constructor (#547)
  * refactor: improve type safe functions (#545)
* Fri Dec 15 2023 ecsos <ecsos@opensuse.org>
- update to 0.20.7:
  * Support Python 3.12
- update to 0.20.6
  * fix: sanitize path when write (#525)
  * fix: allow specify target path in relative path (#530)
  * Avoid AttributeError on OpenBSD (#521)
  * Error appending file: KeyError: 'lastwritetime' (#517)
  * Fixing a string quote in user_guide document(#524)
* Wed Jun 21 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.20.5:
  * Remove root reference from file names (#513)
  * fix typo in the readme (#510)
  * Drop manual GC to improve performance when many files are
    handled. (#489, #490)
  * Fix mypy error
  * Skip deflate64 compression/decompression test on pypy
  * There is an issue in dependency inflate64 library that causes
    SIGABORT and SIGSEGV on pypy
* Wed Dec 21 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.20.2
  * Fix error with good path data, when detecting wrong path with
    new canonical_path(), and drop resolve() call on path.
- Release 0.20.1
  [#]# Security
  * Fix sanity check for path traversal attack(#480)
  * Add path checker in writef() and writestr() methods that
    ignores evil pass.
  - When pass arcname as evil path such as
    "../../../../tmp/evil.sh"
  - it raises ValueError
  * Check symlink and junction is under target folder when
    extraction
- Release 0.20.0
  * Support enhanced deflate compression.(#472)
  * Bump setuptools@63 and setuptools_scm@7 (#473)
  * Deprecate Python 3.6 support (#473)
- Fixes boo#1206141 CVE-2022-44900
* Fri Jul 15 2022 Ben Greiner <code@bnavigator.de>
- Update to version 0.19.0
  * big changelog
- Move tests to multibuild
* Thu Jul 14 2022 Ben Greiner <code@bnavigator.de>
- Remove ancient python-pathlib from the build requirements but
  leave the version as is. An update to the latest version 0.19.0
  would require to package many more dependencies.
- Clean up the spec-file a little bit
- Use pytest. No pure python package should ever be untested.
* Sat Apr  3 2021 Ismail Dönmez <idonmez@suse.com>
- Fix sed line to use python3 and add a replacement for /usr/bin/python
  as well.
* Fri Jan 22 2021 ecsos <ecsos@opensuse.org>
- Initial version 0.11.3
